@@ -1,4 +1,4 @@
-# Copyright (C) 2013 DNAnexus, Inc.
+# Copyright (C) 2013-2014 DNAnexus, Inc.
 #
 # This file is part of dx-toolkit (DNAnexus platform client libraries).
 #
@@ -123,24 +123,13 @@ environment variables:
 
 '''
 
-# Note: The default I/O stream encoding in Python 2.7 (as configured on ubuntu) is ascii, not UTF-8 or the system locale
-# encoding. The lines below attempt to reset it here to avoid having to set it for every I/O operation explicitly.
-# However, this method doesn't work with pypy, so instead we set the environment variable PYTHONIOENCODING=UTF-8 in
-# dx-toolkit environment initialization (dx-toolkit/environment).
-# One other alternative is to use codecs.wrap or sys.stdout = codecs.getwriter('utf8')(sys.stdout).
-# try:
-#     import sys, locale
-#     reload(sys).setdefaultencoding(locale.getdefaultlocale()[1])
-# except:
-#     pass
-
-from __future__ import print_function
+from __future__ import (print_function, unicode_literals)
 
 import os, sys, json, time, logging, platform, collections
 from .packages import requests
 from .packages.requests.exceptions import ConnectionError, HTTPError, Timeout
 from .packages.requests.auth import AuthBase
-from .compat import is_py2
+from .compat import USING_PYTHON2
 
 logger = logging.getLogger(__name__)
 logging.getLogger('dxpy.packages.requests.packages.urllib3.connectionpool').setLevel(logging.ERROR)
@@ -251,26 +240,16 @@ def DXHTTPRequest(resource, data, method='POST', headers=None, auth=True, timeou
     if auth is True:
         auth = AUTH_HELPER
 
-    # When *data* is bytes but *headers* contains Unicode strings, httplib tries to concatenate them and decode *data*,
-    # which should not be done. Also, per HTTP/1.1 headers must be encoded with MIME, but we'll disregard that here, and
-    # just encode them with the Python default (ascii) and fail for any non-ascii content.
-    # TODO: ascertain whether this is a problem in Python 3/make test
-    if is_py2:
-        headers = {k.encode(): v.encode() for k, v in headers.items()}
+    if 'verify' not in kwargs and 'DX_CA_CERT' in os.environ:
+        kwargs['verify'] = os.environ['DX_CA_CERT']
+        if os.environ['DX_CA_CERT'] == 'NOVERIFY':
+            kwargs['verify'] = False
 
     if jsonify_data:
         data = json.dumps(data)
         if 'Content-Type' not in headers and method == 'POST':
             headers['Content-Type'] = 'application/json'
 
-    # If the input is a buffer, its data gets consumed by
-    # requests.request (moving the read position). Record the initial
-    # buffer position so that we can return to it if the request fails
-    # and needs to be retried.
-    rewind_input_buffer_offset = None
-    if hasattr(data, 'seek') and hasattr(data, 'tell'):
-        rewind_input_buffer_offset = data.tell()
-
     headers['DNAnexus-API'] = API_VERSION
     headers['User-Agent'] = USER_AGENT
 
@@ -279,10 +258,22 @@ def DXHTTPRequest(resource, data, method='POST', headers=None, auth=True, timeou
             raise exceptions.DXError("Snappy compression requested, but the snappy module is unavailable")
         headers['accept-encoding'] = 'snappy'
 
-    if 'verify' not in kwargs and 'DX_CA_CERT' in os.environ:
-        kwargs['verify'] = os.environ['DX_CA_CERT']
-        if os.environ['DX_CA_CERT'] == 'NOVERIFY':
-            kwargs['verify'] = False
+    # When *data* is bytes but *headers* contains Unicode text, httplib tries to concatenate them and decode *data*,
+    # which should not be done. Also, per HTTP/1.1 headers must be encoded with MIME, but we'll disregard that here, and
+    # just encode them with the Python default (ascii) and fail for any non-ascii content.
+    # TODO: ascertain whether this is a problem in Python 3/make test
+    if USING_PYTHON2:
+        headers = {k.encode(): v.encode() for k, v in headers.items()}
+        url = url.encode()
+        method = method.encode()
+
+    # If the input is a buffer, its data gets consumed by
+    # requests.request (moving the read position). Record the initial
+    # buffer position so that we can return to it if the request fails
+    # and needs to be retried.
+    rewind_input_buffer_offset = None
+    if hasattr(data, 'seek') and hasattr(data, 'tell'):
+        rewind_input_buffer_offset = data.tell()
 
     last_error = None
     for retry in range(max_retries + 1):
@@ -383,9 +374,8 @@ class DXHTTPOAuth2(AuthBase):
 
     def __call__(self, r):
         if self.security_context["auth_token_type"].lower() == 'bearer':
-            r.headers['Authorization'] = \
-                self.security_context["auth_token_type"] + " " + \
-                self.security_context["auth_token"]
+            auth_header = self.security_context["auth_token_type"] + " " + self.security_context["auth_token"]
+            r.headers[b'Authorization'] = auth_header.encode()
         else:
             raise NotImplementedError("Token types other than bearer are not yet supported")
         return r
