@@ -1,4 +1,4 @@
-# Copyright (C) 2013 DNAnexus, Inc.
+# Copyright (C) 2013-2014 DNAnexus, Inc.
 #
 # This file is part of dx-toolkit (DNAnexus platform client libraries).
 #
@@ -22,6 +22,8 @@ The following helper functions are useful shortcuts for interacting with File ob
 
 '''
 
+from __future__ import (print_function, unicode_literals)
+
 import os, sys, math, mmap, stat
 
 import dxpy
@@ -224,7 +226,7 @@ def upload_local_file(filename=None, file=None, media_type=None, keep_open=False
 
         bytes_available = max(file_size - offset, 0)
         if bytes_available == 0:
-            return ""
+            return b""
 
         return mmap.mmap(fd.fileno(), min(handler._write_bufsize, bytes_available), offset=offset, access=mmap.ACCESS_READ)
 
