@@ -1,4 +1,4 @@
-# Copyright (C) 2013 DNAnexus, Inc.
+# Copyright (C) 2013-2014 DNAnexus, Inc.
 #
 # This file is part of dx-toolkit (DNAnexus platform client libraries).
 #
@@ -18,9 +18,9 @@
 Functions and classes used when launching platform executables from the CLI.
 '''
 
-# TODO: refactor all dx run helper functions here
+from __future__ import (print_function, unicode_literals)
 
-from __future__ import print_function
+# TODO: refactor all dx run helper functions here
 
 import os, sys, json, collections, pipes, shlex
 
