@@ -1,4 +1,4 @@
-# Copyright (C) 2013 DNAnexus, Inc.
+# Copyright (C) 2013-2014 DNAnexus, Inc.
 #
 # This file is part of dx-toolkit (DNAnexus platform client libraries).
 #
@@ -23,7 +23,7 @@ names in the syntax of
 For more details, see external documentation [TODO: Put link here].
 '''
 
-from __future__ import print_function
+from __future__ import (print_function, unicode_literals)
 
 import os, sys, json, re
 
